@@ -42,8 +42,8 @@ class ArgumentParser(arghparse.ArgumentParser):
         return namespace, []
 
 
-class CommitTags(argparse.Action):
-    """Register tags to inject into the commit message footer."""
+class BugTag(argparse.Action):
+    """Register bug-related tag to inject into the commit message footer."""
 
     def __call__(self, parser, namespace, value, option_string=None):
         try:
@@ -55,6 +55,19 @@ class CommitTags(argparse.Action):
         namespace.footer.add((self.dest.capitalize(), url))
 
 
+class CommitTag(argparse.Action):
+    """Register commit tag to inject into the commit message footer."""
+
+    def __call__(self, parser, namespace, value, option_string=None):
+        try:
+            name, val = value.split(':', 1)
+            if not (name and val):
+                raise ValueError('empty name or value')
+        except ValueError:
+            raise argparse.ArgumentError(self, f'invalid commit tag: {value!r}')
+        namespace.footer.add((name.capitalize(), val))
+
+
 commit = ArgumentParser(
     prog='pkgdev commit', description='create git commit',
     parents=(cwd_repo_argparser, git_repo_argparser))
@@ -62,11 +75,14 @@ commit = ArgumentParser(
 commit.add_argument('--pkgcheck-scan', help=argparse.SUPPRESS)
 commit_opts = commit.add_argument_group('commit options')
 commit_opts.add_argument(
-    '-b', '--bug', action=CommitTags,
+    '-b', '--bug', action=BugTag,
     help='add Bug tag for a given Gentoo or upstream bug')
 commit_opts.add_argument(
-    '-c', '--closes', action=CommitTags,
+    '-c', '--closes', action=BugTag,
     help='add Closes tag for a given Gentoo bug or upstream PR URL')
+commit_opts.add_argument(
+    '-T', '--tag', action=CommitTag, metavar='NAME:VALUE',
+    help='add commit tag')
 commit_opts.add_argument(
     '-n', '--dry-run', action='store_true',
     help='pretend to create commit',
@@ -74,7 +90,7 @@ commit_opts.add_argument(
         Perform all actions without creating a commit.
     """)
 commit_opts.add_argument(
-    '-s', '--scan', action='store_true',
+    '-s', '--scan', nargs='?', const=True, action=arghparse.StoreBool,
     help='run pkgcheck against staged changes',
     docs="""
         By default, ``pkgdev commit`` doesn't scan for QA errors. This option
@@ -134,7 +150,7 @@ add_actions.add_argument(
 class _HistoricalRepo(UnconfiguredTree):
     """Repository of historical packages stored in a temporary directory."""
 
-    def __init__(self, repo, *args, **kwargs):
+    def __init__(self, repo):
         self.__parent_repo = repo
         self.__tmpdir = tempfile.TemporaryDirectory()
         self.__created = False
@@ -229,7 +245,8 @@ class MetadataSummary(ChangeSummary):
         try:
             old_pkg = self.old_repo.match(atom)[0]
             new_pkg = self.repo.match(atom)[0]
-        except IndexError:
+        except IndexError:  # pragma: no cover
+            # broken ebuild should be caught during manifesting or scanning
             return
 
         if old_pkg.maintainers != new_pkg.maintainers:
@@ -302,8 +319,8 @@ class PkgSummary(ChangeSummary):
             pkgs = sorted(x for x in self.repo.match(atom.unversioned_atom) if x <= atom)
             try:
                 old_pkg, new_pkg = pkgs[-2:]
-            except ValueError:
-                # probably a broken ebuild
+            except ValueError:  # pragma: no cover
+                # broken ebuild should be caught during manifesting or scanning
                 return
 
             if old_pkg.eapi in new_pkg.eapi.inherits[1:]:
@@ -336,7 +353,8 @@ class PkgSummary(ChangeSummary):
             try:
                 old_pkg = self.old_repo.match(atom)[0]
                 new_pkg = self.repo.match(atom)[0]
-            except IndexError:
+            except IndexError:  # pragma: no cover
+                # broken ebuild should be caught during manifesting or scanning
                 return
 
             if old_pkg.eapi in new_pkg.eapi.inherits[1:]:
@@ -349,13 +367,13 @@ class PkgSummary(ChangeSummary):
                 if removed == {f'~{x}' for x in added}:
                     action = f'stabilize {atom.fullver}'
                     msg = f"{action} for {', '.join(sorted(added))}"
-                elif not removed and all(x.startswith('~') for x in added):
-                    action = f'keyword {atom.fullver}'
-                    msg = f"{action} for {', '.join(sorted(added))}"
                 elif removed == {x.lstrip('~') for x in added}:
                     action = f'destabilize {atom.fullver}'
                     msg = f"{action} for {', '.join(sorted(added))}"
-                elif not added:
+                elif added:
+                    action = f'keyword {atom.fullver}'
+                    msg = f"{action} for {', '.join(sorted(added))}"
+                else:
                     action = f'unkeyword {atom.fullver}'
                     msg = f"{action} for {', '.join(sorted(removed))}"
 
@@ -419,7 +437,7 @@ class GitChanges(UserDict):
     def summary(self):
         """Determine commit message summary."""
         # all changes made on the same package
-        if len({x.atom.unversioned_atom for x in self.pkg_changes}) == 1:
+        if len({x.atom.key for x in self.pkg_changes}) == 1:
             if not self.ebuild_changes:
                 if len(self.pkg_changes) == 1:
                     if self.pkg_changes[0].path.endswith('/Manifest'):
@@ -466,7 +484,7 @@ class PkgChange(Change):
 
     @property
     def prefix(self):
-        return f'{self.atom.unversioned_atom}: '
+        return f'{self.atom.key}: '
 
 
 def determine_changes(options):
@@ -572,7 +590,8 @@ def determine_msg_args(options, changes):
             else:
                 args.extend(['-F', tmp.name])
 
-            # explicitly close and delete tempfile on exit
+            # Explicitly register tempfile removal so the object isn't garbage
+            # collected and removed when leaving function scope.
             atexit.register(tmp.close)
 
     return args
@@ -605,18 +624,32 @@ def _commit(options, out, err):
     # determine changes from staged files
     changes = determine_changes(options)
 
+    _untracked_ebuild_re = re.compile(r'^\?\? (?P<category>[^/]+)/[^/]+/(?P<package>[^/]+)\.ebuild$')
+    # update manifests for existing packages
     if atoms := {x.atom.unversioned_atom for x in changes.ebuild_changes}:
-        # manifest all changed packages
-        failed = repo.operations.digests(
-            domain=options.domain,
-            restriction=packages.OrRestriction(*atoms),
-            observer=observer_mod.formatter_output(out))
-        if any(failed):
-            return 1
+        if pkgs := {x.versioned_atom for x in repo.itermatch(packages.OrRestriction(*atoms))}:
+            # pull all matches and drop untracked ebuilds
+            p = git.run(
+                'status', '--porcelain=v1', '-u', '-z', "*.ebuild",
+                cwd=repo.location, stdout=subprocess.PIPE)
+            for path in p.stdout.strip('\x00').split('\x00'):
+                if mo := _untracked_ebuild_re.match(path):
+                    try:
+                        untracked = atom_cls(f"={mo.group('category')}/{mo.group('package')}")
+                        pkgs.discard(untracked)
+                    except MalformedAtom:
+                        continue
 
-        # include existing Manifest files for staging
-        manifests = (pjoin(repo.location, f'{x.cpvstr}/Manifest') for x in atoms)
-        git_add_files.extend(filter(os.path.exists, manifests))
+            # manifest all staged or committed packages
+            failed = repo.operations.manifest(
+                options.domain, packages.OrRestriction(*pkgs),
+                observer=observer_mod.formatter_output(out))
+            if any(failed):
+                return 1
+
+            # include existing Manifest files for staging
+            manifests = (pjoin(repo.location, f'{x.key}/Manifest') for x in atoms)
+            git_add_files.extend(filter(os.path.exists, manifests))
 
     # mangle files
     if options.mangle:
