@@ -112,18 +112,22 @@ class TestPkgdevCommitParseArgs:
             for opt in ('-b', '--bug'):
                 options, _ = tool.parse_args(['commit', opt, '1'])
                 assert options.footer == {('Bug', 'https://bugs.gentoo.org/1')}
+
             # bug URLs
             for opt in ('-b', '--bug'):
                 options, _ = tool.parse_args(['commit', opt, 'https://bugs.gentoo.org/2'])
                 assert options.footer == {('Bug', 'https://bugs.gentoo.org/2')}
+
             # bug IDs
             for opt in ('-c', '--closes'):
                 options, _ = tool.parse_args(['commit', opt, '1'])
                 assert options.footer == {('Closes', 'https://bugs.gentoo.org/1')}
+
             # bug URLs
             for opt in ('-c', '--closes'):
                 options, _ = tool.parse_args(['commit', opt, 'https://bugs.gentoo.org/2'])
                 assert options.footer == {('Closes', 'https://bugs.gentoo.org/2')}
+
             # bad URL
             for opt in ('-b', '-c'):
                 with pytest.raises(SystemExit) as excinfo:
@@ -133,6 +137,26 @@ class TestPkgdevCommitParseArgs:
                 assert not out
                 assert 'invalid URL: bugs.gentoo.org/1' in err
 
+            # generic tags
+            for opt in ('-T', '--tag'):
+                for value, expected in (
+                        ('tag:value', ('Tag', 'value')),
+                        ('tag:multiple values', ('Tag', 'multiple values')),
+                        ('tag:multiple:values', ('Tag', 'multiple:values')),
+                        ):
+                    options, _ = tool.parse_args(['commit', opt, value])
+                    assert options.footer == {expected}
+
+            # bad tags
+            for opt in ('-T', '--tag'):
+                for value in ('', ':', 'tag:', ':value', 'tag'):
+                    with pytest.raises(SystemExit) as excinfo:
+                        tool.parse_args(['commit', opt, value])
+                    assert excinfo.value.code == 2
+                    out, err = capsys.readouterr()
+                    assert not out
+                    assert 'invalid commit tag' in err
+
 
 class TestPkgdevCommit:
 
@@ -388,7 +412,7 @@ class TestPkgdevCommit:
         git_repo.add_all('cat/pkg-0')
 
         def commit():
-            with os_environ(GIT_EDITOR="sed -i '1s/$/commit/'"), \
+            with os_environ(GIT_EDITOR="sed -i '1s/$/summary/'"), \
                     patch('sys.argv', self.args + ['-a']), \
                     pytest.raises(SystemExit) as excinfo, \
                     chdir(git_repo.path):
@@ -447,6 +471,11 @@ class TestPkgdevCommit:
         repo.create_ebuild('cat/pkg-6', eapi='7')
         assert commit() == 'cat/pkg: update EAPI 6 -> 7'
 
+        # multiple ebuild modifications don't get a generated summary
+        repo.create_ebuild('cat/pkg-5', keywords=['~amd64'])
+        repo.create_ebuild('cat/pkg-6', keywords=['~amd64'])
+        assert commit() == 'cat/pkg: summary'
+
         # large number of additions in a single commit
         for v in range(10000, 10010):
             repo.create_ebuild(f'cat/pkg-{v}')
