@@ -1,6 +1,7 @@
 import os
 import textwrap
 from functools import partial
+from io import StringIO
 from unittest.mock import patch
 
 import pytest
@@ -38,16 +39,23 @@ class TestPkgdevPushParseArgs:
         git_repo = make_git_repo(repo.location)
         with chdir(git_repo.path):
             options, _ = tool.parse_args(['push', 'origin', 'master'])
-        assert options.push_args == ['origin', 'master']
+            assert options.push_args == ['origin', 'master']
+            options, _ = tool.parse_args(['push', '-n', '--signed'])
+            assert '--dry-run' in options.push_args
+            assert '--signed' in options.push_args
 
-    def test_gentoo_repo_git_push_args(self, make_repo, make_git_repo, tool):
-        """Unknown arguments for ``pkgdev push`` are passed to ``git push``."""
-        repo = make_repo(repo_id='gentoo')
+    def test_scan_args(self, repo, make_git_repo, tool):
         git_repo = make_git_repo(repo.location)
-        with chdir(git_repo.path):
-            options, _ = tool.parse_args(['push', '-n'])
-        assert '--signed' in options.push_args
-        assert '--dry-run' in options.push_args
+        repo.create_ebuild('cat/pkg-0')
+        git_repo.add_all('cat/pkg-0', commit=False)
+        # pkgcheck isn't run in verbose mode by default
+        with chdir(repo.location):
+            options, _ = tool.parse_args(['commit'])
+        assert '-v' not in options.scan_args
+        # verbosity level is passed down to pkgcheck
+        with chdir(repo.location):
+            options, _ = tool.parse_args(['commit', '-v'])
+        assert '-v' in options.scan_args
 
 
 class TestPkgdevPush:
@@ -108,7 +116,8 @@ class TestPkgdevPush:
         """)
 
         # but failures can be ignored to push anyway
-        with patch('sys.argv', self.args + ['--ignore-failures']), \
+        with patch('sys.argv', self.args + ['--ask']), \
+                patch('sys.stdin', StringIO('y\n')), \
                 pytest.raises(SystemExit) as excinfo, \
                 chdir(self.child_git_repo.path):
             self.script()
